import org.apache.commons.httpclient.*
import org.apache.commons.httpclient.methods.*
import org.apache.commons.httpclient.auth.AuthScope
import com.urbancode.air.AirPluginTool

final def workDir = new File('.').canonicalFile
final def airTool = new AirPluginTool(args[0], args[1])
final def props = airTool.getStepProperties()


def timeout = props['timeout']
def user = props['user']
def url = props['url']
def verifyString = props['verifyString']
def failIfFound = props['failIfFound'].toBoolean()
def base_url = new URL(url).getHost()
def port = new URL(url).getPort()
def password = (props['password']?props['password']:(props['passScript']?props['passScript']:null))

println("URL : ${url}")
println("Verify String : ${verifyString}")
println("Timeout : " + timeout)
println("User : ${user}")
println("Fail If Found: $failIfFound")
println("Host : ${base_url}")
println("Port : ${port}")

HttpClient client = new HttpClient()
if(password) {
    client.getParams().setAuthenticationPreemptive(true)
    Credentials defaultcreds = new UsernamePasswordCredentials(user, password)
    client.getState().setCredentials(new AuthScope(base_url, port), defaultcreds)
}
if(timeout) {
	client.setConnectionTimeout(Integer.valueOf(timeout))
}

def HttpMethod method = null
def response = null
def result = 0
def success = true;
try {
    method = new GetMethod(url)
    result = client.executeMethod(method)
    response = method.getResponseBodyAsString()
}
finally {
    if(method != null) {
        method.releaseConnection()
    }
}
if(result <200 || result > 299) {
    println("Error result code recieved : ${result}")
    println(response)
    success = false
}
else if(!response) {
    println("No response received from url : ${url}")
    success = false
}
else if(response =~ verifyString) {
    println("Response matches the verify String")
    if (failIfFound) {
        success = false
    }
}
else {
    println("Response did not match the verify string")
    println(response)
    if (!failIfFound) {
        success = false
    }
}

if (!success) System.exit(1)

System.exit 0
